==> quick-system-info-gui_23.09.01.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX ウェルカム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>&amp;Copy for forum</source>
        <translation>フォーラム用にコピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>表示されたシステム情報をテキストファイルに保存します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>テキストの保存...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>表示されたシステム情報をクリップボードにコピーし、さらに [CODE][/CODE] タグで囲んでフォーラム投稿で利用できるようにします。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>一覧から選択したシステム情報を書庫ファイルとして保存します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>保存(&amp;S)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>About...</source>
        <translation>概要...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="176"/>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Quick System Info</source>
        <translation>クイックシステム情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>読み込み中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Quick-System-Info-gui について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Find &amp;Next</source>
        <translation>次を検索(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>すべて選択(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>選択内容を元に戻す</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Program for displaying a quick system info report</source>
        <translation>クイックシステム情報を出力するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Save (×%1)...</source>
        <translation>保存(&amp;S) (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Find what:</source>
        <translation>検索候補(&amp;F):</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Match c&amp;ase</source>
        <translation>一致(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>Match &amp;whole word only</source>
        <translation>完全一致(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Direction</source>
        <translation>検索方向</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>&amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>&amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>&quot;%1&quot; が見つかりませんでした</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">更新履歴</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Save System Information</source>
        <translation>システム情報の保存</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>System information saved.</source>
        <translation>システム情報を保存しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Could not save system information.</source>
        <translation>システム情報を保存できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>history</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Quick System Info (gui)</source>
        <translation>クイックシステム情報 (GUI で)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>フォーラム用にコピー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>平文テキスト形式でコピー</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>このプログラムは標準ユーザーで実行して下さい。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>このツールはクイックシステム情報をグラフィカル表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>

==> quick-system-info-gui_24.12.09.tar.xz: quick-system-info-gui/translations/quick-system-info-gui_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX ウェルカム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>&amp;Copy for forum</source>
        <translation>フォーラム用にコピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>表示されたシステム情報をテキストファイルに保存します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Save text...</source>
        <translation>テキストの保存...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="71"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>表示されたシステム情報をクリップボードにコピーし、さらに [CODE][/CODE] タグで囲んでフォーラム投稿で利用できるようにします。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>一覧から選択したシステム情報を書庫ファイルとして保存します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Save...</source>
        <translation>保存(&amp;S)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="139"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>About...</source>
        <translation>概要...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <location filename="../mainwindow.cpp" line="325"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>Quick System Info</source>
        <translation>クイックシステム情報</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>読み込み中...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Quick-System-Info-gui について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>&amp;Find...</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>Find &amp;Next</source>
        <translation>次を検索(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="115"/>
        <source>Select &amp;All</source>
        <translation>すべて選択(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="121"/>
        <source>Revert Selection</source>
        <translation>選択内容を元に戻す</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>Program for displaying a quick system info report</source>
        <translation>クイックシステム情報を出力するプログラム</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Open folder</source>
        <translation>フォルダを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>&amp;Save (×%1)...</source>
        <translation>保存(&amp;S) (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>&amp;Find what:</source>
        <translation>検索候補(&amp;F):</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Match c&amp;ase</source>
        <translation>一致(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Match &amp;whole word only</source>
        <translation>完全一致(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>Direction</source>
        <translation>検索方向</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>&amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>&quot;%1&quot; が見つかりませんでした</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">更新履歴</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Save System Information</source>
        <translation>システム情報の保存</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>System information saved.</source>
        <translation>システム情報を保存しました。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Could not save system information.</source>
        <translation>システム情報を保存できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>history</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <source>Quick System Info (gui)</source>
        <translation type="vanished">クイックシステム情報 (GUI で)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Copy for forum</source>
        <translation>フォーラム用にコピー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>Plain text copy</source>
        <translation>平文テキスト形式でコピー</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>このプログラムは通常のユーザで実行してください。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>このツールはクイックシステム情報をグラフィカル表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
</context>
</TS>
